==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/cloudfront/kotlin/inputs/ResponseHeadersPolicyCorsConfigAccessControlAllowHeadersArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.cloudfront.kotlin.inputs

import com.pulumi.aws.cloudfront.inputs.ResponseHeadersPolicyCorsConfigAccessControlAllowHeadersArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property items
 */
public data class ResponseHeadersPolicyCorsConfigAccessControlAllowHeadersArgs(
    public val items: Output<List<String>>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.cloudfront.inputs.ResponseHeadersPolicyCorsConfigAccessControlAllowHeadersArgs> {
    override fun toJava():
        com.pulumi.aws.cloudfront.inputs.ResponseHeadersPolicyCorsConfigAccessControlAllowHeadersArgs =
        com.pulumi.aws.cloudfront.inputs.ResponseHeadersPolicyCorsConfigAccessControlAllowHeadersArgs.builder()
            .items(items?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [ResponseHeadersPolicyCorsConfigAccessControlAllowHeadersArgs].
 */
@PulumiTagMarker
public class ResponseHeadersPolicyCorsConfigAccessControlAllowHeadersArgsBuilder internal
constructor() {
    private var items: Output<List<String>>? = null

    /**
     * @param value
     */
    @JvmName("eimhmtxhnltkvbfc")
    public suspend fun items(`value`: Output<List<String>>) {
        this.items = value
    }

    @JvmName("msmbacdpvswqecjb")
    public suspend fun items(vararg values: Output<String>) {
        this.items = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("udkmvngclayvpjej")
    public suspend fun items(values: List<Output<String>>) {
        this.items = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("nfqhpudmgppqygxc")
    public suspend fun items(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.items = mapped
    }

    /**
     * @param values
     */
    @JvmName("yedambbihqpkvutn")
    public suspend fun items(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.items = mapped
    }

    internal fun build(): ResponseHeadersPolicyCorsConfigAccessControlAllowHeadersArgs =
        ResponseHeadersPolicyCorsConfigAccessControlAllowHeadersArgs(
            items = items,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/cloudfront/kotlin/inputs/ResponseHeadersPolicyCorsConfigAccessControlAllowHeadersArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.cloudfront.kotlin.inputs

import com.pulumi.aws.cloudfront.inputs.ResponseHeadersPolicyCorsConfigAccessControlAllowHeadersArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property items
 */
public data class ResponseHeadersPolicyCorsConfigAccessControlAllowHeadersArgs(
    public val items: Output<List<String>>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.cloudfront.inputs.ResponseHeadersPolicyCorsConfigAccessControlAllowHeadersArgs> {
    override fun toJava(): com.pulumi.aws.cloudfront.inputs.ResponseHeadersPolicyCorsConfigAccessControlAllowHeadersArgs =
        com.pulumi.aws.cloudfront.inputs.ResponseHeadersPolicyCorsConfigAccessControlAllowHeadersArgs.builder()
            .items(items?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [ResponseHeadersPolicyCorsConfigAccessControlAllowHeadersArgs].
 */
@PulumiTagMarker
public class ResponseHeadersPolicyCorsConfigAccessControlAllowHeadersArgsBuilder internal constructor() {
    private var items: Output<List<String>>? = null

    /**
     * @param value
     */
    @JvmName("eysxqpmfrsiykfln")
    public suspend fun items(`value`: Output<List<String>>) {
        this.items = value
    }

    @JvmName("fronvrucinplhsru")
    public suspend fun items(vararg values: Output<String>) {
        this.items = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("ivjrfaibcevmopue")
    public suspend fun items(values: List<Output<String>>) {
        this.items = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("pcwwlhgkbdlqguxs")
    public suspend fun items(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.items = mapped
    }

    /**
     * @param values
     */
    @JvmName("hsnmiqfjcqylnrle")
    public suspend fun items(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.items = mapped
    }

    internal fun build(): ResponseHeadersPolicyCorsConfigAccessControlAllowHeadersArgs =
        ResponseHeadersPolicyCorsConfigAccessControlAllowHeadersArgs(
            items = items,
        )
}
